@@ -2,7 +2,15 @@ import builtins
 import sys
 
 
-def echo(*message, status=None, silent=False, curr_verbosity=0, expc_verbosity=0, end='\n', flush=False):
+def echo(
+    *message,
+    status=None,
+    silent=False,
+    curr_verbosity=0,
+    expc_verbosity=0,
+    end='\n',
+    flush=False
+):
     toggle_silent = False
     toggle_verbose = 0
     try:
