@@ -14,10 +14,12 @@ def sharedflows():
     pass
 
 
-def _get_a_list_of_shared_flows(username, password, mfa_secret, token, zonename, org, profile, prefix=None, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_a_list_of_shared_flows(
-        prefix=prefix
-    )
+def _get_a_list_of_shared_flows(
+    username, password, mfa_secret, token, zonename, org, profile, prefix=None, **kwargs
+):
+    return Sharedflows(
+        gen_auth(username, password, mfa_secret, token, zonename), org
+    ).get_a_list_of_shared_flows(prefix=prefix)
 
 
 @sharedflows.command(
@@ -31,7 +33,9 @@ def list(*args, **kwargs):
     console.echo(_get_a_list_of_shared_flows(*args, **kwargs))
 
 
-def _import_a_shared_flow(username, password, mfa_secret, token, zonename, org, profile, file, name, **kwargs):
+def _import_a_shared_flow(
+    username, password, mfa_secret, token, zonename, org, profile, file, name, **kwargs
+):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
         .import_a_shared_flow(file, name)
@@ -63,8 +67,14 @@ def import_a_shared_flow(*args, **kwargs):
 #     pass
 
 
-def _get_a_shared_flow(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
-    return Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_a_shared_flow(name).text
+def _get_a_shared_flow(
+    username, password, mfa_secret, token, zonename, org, profile, name, **kwargs
+):
+    return (
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .get_a_shared_flow(name)
+        .text
+    )
 
 
 @sharedflows.command(help='Gets a shared flow by name, including a list of its revisions.')
@@ -94,7 +104,14 @@ def _deploy_a_shared_flow(
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
-        .deploy_a_shared_flow(environment, name, revision_number, override=override, delay=delay, shared_flow_file=file)
+        .deploy_a_shared_flow(
+            environment,
+            name,
+            revision_number,
+            override=override,
+            delay=delay,
+            shared_flow_file=file,
+        )
         .text
     )
 
@@ -108,7 +125,11 @@ def _deploy_a_shared_flow(
 @common_verbose_options
 @click.option('-e', '--environment', help='environment', required=True)
 @click.option('-n', '--name', help='name', required=True)
-@optgroup.group('Deployment options', cls=RequiredMutuallyExclusiveOptionGroup, help='The deployment options')
+@optgroup.group(
+    'Deployment options',
+    cls=RequiredMutuallyExclusiveOptionGroup,
+    help='The deployment options',
+)
 @optgroup.option(
     '-f',
     '--file',
@@ -134,7 +155,17 @@ def deploy(*args, **kwargs):
 
 
 def _undeploy_a_shared_flow(
-    username, password, mfa_secret, token, zonename, org, profile, environment, name, revision_number, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    environment,
+    name,
+    revision_number,
+    **kwargs
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -155,7 +186,16 @@ def undeploy(*args, **kwargs):
 
 
 def _get_deployment_environments_for_shared_flows(
-    username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    revision_number,
+    **kwargs
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -164,7 +204,9 @@ def _get_deployment_environments_for_shared_flows(
     )
 
 
-@sharedflows.command(help='Gets an array of the environments to which the shared flow is deployed.')
+@sharedflows.command(
+    help='Gets an array of the environments to which the shared flow is deployed.'
+)
 @common_auth_options
 @common_silent_options
 @common_verbose_options
@@ -186,7 +228,16 @@ def _delete_a_shared_flow(self, shared_flow_name):
 
 
 def _get_the_shared_flow_attached_to_a_flow_hook(
-    username, password, mfa_secret, token, zonename, org, profile, environment, flow_hook, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    environment,
+    flow_hook,
+    **kwargs
 ):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -202,12 +253,16 @@ def _get_the_shared_flow_attached_to_a_flow_hook(
 @common_silent_options
 @common_verbose_options
 @click.option('-e', '--environment', help='environment', required=True)
-@click.option('--flow-hook', help='flow hook to which the shared flow is attached', required=True)
+@click.option(
+    '--flow-hook', help='flow hook to which the shared flow is attached', required=True
+)
 def get_flow_hook(*args, **kwargs):
     console.echo(_get_the_shared_flow_attached_to_a_flow_hook(*args, **kwargs))
 
 
-def _get_shared_flow_deployments(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
+def _get_shared_flow_deployments(
+    username, password, mfa_secret, token, zonename, org, profile, name, **kwargs
+):
     return (
         Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
         .get_shared_flow_deployments(name)
@@ -224,9 +279,13 @@ def get_deployments(*args, **kwargs):
     console.echo(_get_shared_flow_deployments(*args, **kwargs))
 
 
-def _get_shared_flow_revisions(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
+def _get_shared_flow_revisions(
+    username, password, mfa_secret, token, zonename, org, profile, name, **kwargs
+):
     return (
-        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org).get_shared_flow_revisions(name).text
+        Sharedflows(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .get_shared_flow_revisions(name)
+        .text
     )
 
 
